# Kabomu Library for Python

This is a port of the Kabomu library originally written in C#.NET to Python.

In a nutshell, Kabomu enables building quasi web applications that can connect endpoints within localhost and even within an OS process, through IPC mechanisms other than TCP.

See the [repository for the .NET version](https://github.com/aaronicsubstances/cskabomu) for more details.

## Install

```
pip install kabomu
```

## Usage

The entry classes of the libary are [StandardQuasiHttpClient](https://github.com/aaronicsubstances/kabomu-python/blob/master/kabomu/StandardQuasiHttpClient.py) and [StandardQuasiHttpServer](https://github.com/aaronicsubstances/kabomu-python/blob/master/kabomu/StandardQuasiHttpServer.py).

See [Examples](https://github.com/aaronicsubstances/kabomu-python/tree/master/examples) folder for sample file serving programs.
